ADADMIRE
========

Welcome to the documentation website of adadmire.

.. toctree::
   :maxdepth: 1

   Installation <installation>
   Usage <usage>
   Modules <modules>
   Contributing <contributing>
   Testing <testing>
   Documentation <documentation>
   Index <genindex>

